# h5pywrappers

[![Test library](https://github.com/mrfitzpa/h5pywrappers/actions/workflows/test_library.yml/badge.svg)](https://github.com/mrfitzpa/h5pywrappers/actions/workflows/test_library.yml)
[![Code Coverage](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/mrfitzpa/6c0ddb605956db582842599ae0dbad81/raw/h5pywrappers_coverage_badge.json)](https://github.com/mrfitzpa/h5pywrappers/actions/workflows/measure_code_coverage.yml)
[![Documentation](https://img.shields.io/badge/docs-read-brightgreen)](https://mrfitzpa.github.io/h5pywrappers)
[![PyPi Version](https://img.shields.io/pypi/v/h5pywrappers.svg)](https://pypi.org/project/h5pywrappers)
[![Conda-Forge Version](https://img.shields.io/conda/vn/conda-forge/h5pywrappers.svg)](https://anaconda.org/conda-forge/h5pywrappers)
[![License](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

`h5pywrappers` is a simple Python library that contains several functions used
to facilitate loading data from and saving data to HDF5 files. These functions
are wrappers that call functions from the
[`h5py`](https://docs.h5py.org/en/stable/) library.

Visit the `h5pywrappers`
[website](https://mrfitzpa.github.io/h5pywrappers) for a web version of the
installation instructions, the reference guide, and the examples archive.

<!--
For those reading raw .rst files, see file `docs/INSTALL.rst` for instructions
on installing the `h5pywrappers` library.
-->